Module beetle_collatz::decrease_steps
source · Expand description
For checking how many steps a number takes to decrease.
Functions
- Returns how many steps ‘n’ takes to decreaseb below its starting value
For checking how many steps a number takes to decrease.