Function beetle_collatz::divide_while_even
source · pub fn divide_while_even(n: NonZeroU128) -> u128Expand description
This has the effect of dividing a number by 2 until it is odd. Odd numbers are simply returned.
pub fn divide_while_even(n: NonZeroU128) -> u128This has the effect of dividing a number by 2 until it is odd. Odd numbers are simply returned.