Function beetle_collatz::transformations
source · pub fn transformations<T: Collatz>(
__arg0: NonZeroUnchecked<T>
) -> Option<Vec<T>>Expand description
Returns all the numbers N becomes on its way to falling to one.
pub fn transformations<T: Collatz>(
__arg0: NonZeroUnchecked<T>
) -> Option<Vec<T>>Returns all the numbers N becomes on its way to falling to one.