Function beetle_collatz::steps::alpha
source · pub fn alpha<T: Collatz>(n: NonZeroUnchecked<T>) -> u32Expand description
Counts how many steps N takes to reach 1. Probably slower than other functions in this module.
pub fn alpha<T: Collatz>(n: NonZeroUnchecked<T>) -> u32Counts how many steps N takes to reach 1. Probably slower than other functions in this module.