Module beetle_collatz::check_range
source · Expand description
For checking to see if ranges of numbers fall to 1
Functions
- Checks a range of numbers to ensure they all fall to 1.
- Same as check_range_unoptimized but uses fall::omega_boolean instead of fall::standard_boolean
- Same as check_range_omega, but takes advantage of knowing all the numbers in the range are odd first