Module beetle_collatz::fall
source · Expand description
Contains functions that apply the rules of the collatz conjecture until a number reaches one
Functions
- Applies the rules of the collatz conjecture until a number reaches one, returning whether it succeeds or not. Success is marked by a number reaching one, and no errors along the way.
- fall::alpha but MUCH FASTER. Assumes you have already checked all numbers < START