Function beetle_collatz::divide_while_even
source · Expand description
This has the effect of dividing a number by 2 until it is odd. Odd numbers are simply returned.
This has the effect of dividing a number by 2 until it is odd. Odd numbers are simply returned.