Function beetle_collatz::divide_while_even
source · Expand description
A collection of functions relating to the Collatz conjecture This has the effect of dividing a number by 2 until it is odd. Odd numbers are simply returned.
A collection of functions relating to the Collatz conjecture This has the effect of dividing a number by 2 until it is odd. Odd numbers are simply returned.