Module beetle_collatz::steps_range
source · Expand description
Functions for mapping integers to the number of steps they take to reach 1.
Functions
- Maps each number N in the range
numsto its steps to reach 1 using steps::basic. Performance should be pretty good, but consider using steps_range::omega for better performance. - Ideally much faster than steps_range::alpha, by use of steps::omega instea of steps::alpha.